==> ukelli-ui-3.0.0.tgz: package/core/chart-dom/chart.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import React, { PureComponent } from 'react';
import { Call } from 'basic-helper';
import { Loading } from '../loading';
import { LoadScript } from '../utils/load-stuff';
var chartjsURL = '';
var isLoading = false;
var ChartCom = /** @class */ (function (_super) {
    __extends(ChartCom, _super);
    function ChartCom(props) {
        var _this = _super.call(this, props) || this;
        _this.componentWillUnmount = function () {
            _this.Chart && _this.Chart.destroy && _this.Chart.destroy();
        };
        _this.loadChart = function (callback) { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        isLoading = true;
                        return [4 /*yield*/, LoadScript({
                                src: chartjsURL,
                            })];
                    case 1:
                        _a.sent();
                        this.setState({
                            loading: false,
                        });
                        Call(callback);
                        isLoading = false;
                        return [2 /*return*/];
                }
            });
        }); };
        _this.renderChart = function () {
            if (!window.Chart) {
                if (_this.timer)
                    clearTimeout(_this.timer);
                if (isLoading || !_this.lineChart) {
                    /** 确保 chartjs 加载成功，以及 canvas 准备妥当 */
                    _this.timer = setTimeout(function () {
                        _this.setState({
                            loading: false,
                        });
                        _this.renderChart();
                    }, 200);
                }
                else {
                    _this.loadChart(_this._renderChart);
                }
            }
            else {
                _this._renderChart();
            }
        };
        _this._renderChart = function () {
            var _a = _this.props, data = _a.data, type = _a.type, _b = _a.options, options = _b === void 0 ? {} : _b, id = _a.id;
            // const ctx = document.querySelector(`#${id}`);
            var ctx = _this.lineChart;
            if (_this.Chart) {
                Object.assign(_this.Chart, {
                    data: data, type: type, options: options
                });
                _this.Chart.update();
            }
            else {
                _this.Chart = new window.Chart(ctx, {
                    type: type,
                    data: data,
                    options: options
                });
            }
        };
        _this.state = {
            loading: !window.Chart,
        };
        return _this;
    }
    ChartCom.prototype.render = function () {
        var _this = this;
        var loading = this.state.loading;
        var _a = this.props, id = _a.id, height = _a.height, width = _a.width;
        return (React.createElement(Loading, { loading: loading },
            React.createElement("canvas", { className: "lineChart", id: id, ref: function (e) {
                    _this.lineChart = e;
                }, style: { width: width, height: height } })));
    };
    /**
     * 设置 Chart js 库的获取地址
     *
     * @static
     * @memberof ChartCom
     * @public
     */
    ChartCom.setChartJSPath = function (path) {
        chartjsURL = path.replace(/\/$/, "/");
    };
    ChartCom.defaultProps = {
        type: 'line',
        id: 'ukeChart',
        height: '100%',
        width: '100%',
    };
    return ChartCom;
}(PureComponent));
export default ChartCom;

==> ukelli-ui-3.3.1.tgz: package/core/chart-dom/chart.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import React, { PureComponent } from 'react';
import { Call } from 'basic-helper';
import { Loading } from '../loading';
import { LoadScript } from '../utils/load-stuff';
var chartjsURL = '';
var isLoading = false;
var ChartCom = /** @class */ (function (_super) {
    __extends(ChartCom, _super);
    function ChartCom(props) {
        var _this = _super.call(this, props) || this;
        _this.componentWillUnmount = function () {
            _this.Chart && _this.Chart.destroy && _this.Chart.destroy();
        };
        _this.loadChart = function (callback) { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        isLoading = true;
                        return [4 /*yield*/, LoadScript({
                                src: chartjsURL,
                            })];
                    case 1:
                        _a.sent();
                        this.setState({
                            loading: false,
                        });
                        Call(callback);
                        isLoading = false;
                        return [2 /*return*/];
                }
            });
        }); };
        _this.renderChart = function () {
            if (!window.Chart) {
                if (_this.timer)
                    clearTimeout(_this.timer);
                if (isLoading || !_this.lineChart) {
                    /** 确保 chartjs 加载成功，以及 canvas 准备妥当 */
                    _this.timer = setTimeout(function () {
                        _this.setState({
                            loading: false,
                        });
                        _this.renderChart();
                    }, 200);
                }
                else {
                    _this.loadChart(_this._renderChart);
                }
            }
            else {
                _this._renderChart();
            }
        };
        _this._renderChart = function () {
            var _a = _this.props, data = _a.data, type = _a.type, _b = _a.options, options = _b === void 0 ? {} : _b, id = _a.id;
            // const ctx = document.querySelector(`#${id}`);
            var ctx = _this.lineChart;
            if (_this.Chart) {
                Object.assign(_this.Chart, {
                    data: data, type: type, options: options
                });
                _this.Chart.update();
            }
            else {
                _this.Chart = new window.Chart(ctx, {
                    type: type,
                    data: data,
                    options: options
                });
            }
        };
        _this.state = {
            loading: !window.Chart,
        };
        return _this;
    }
    ChartCom.prototype.render = function () {
        var _this = this;
        var loading = this.state.loading;
        var _a = this.props, id = _a.id, height = _a.height, width = _a.width;
        return (React.createElement(Loading, { loading: loading },
            React.createElement("canvas", { className: "lineChart", id: id, ref: function (e) {
                    _this.lineChart = e;
                }, style: { width: width, height: height } })));
    };
    /**
     * 设置 Chart js 库的获取地址
     *
     * @static
     * @memberof ChartCom
     * @public
     */
    ChartCom.setChartJSPath = function (path) {
        chartjsURL = path.replace(/\/$/, "/");
    };
    ChartCom.defaultProps = {
        type: 'line',
        id: 'ukeChart',
        height: '100%',
        width: '100%',
    };
    return ChartCom;
}(PureComponent));
export default ChartCom;
